@@ -77,19 +77,27 @@ if __name__ == "__main__":
     if len(sys.argv)<2:
         print "You must suppy a ProviderJSON file to validate"
         print "Example: python validate.py [ProivderJSON]"
+        sys.exit(1)
     else:
         pjson_file = sys.argv[1]
     
+    
+    
     #Open the file
-    fh = open(pjson_file, 'r')
     
-    j = fh.read()
-    
-    errors = validate_pjson(j)
-    
-    errors_json =  json.dumps(errors, indent =4)
-    print errors_json
+    try:
+        fh = open(pjson_file, 'r')
+        
+        j = fh.read()
+        
+        errors = validate_pjson(j)
+        
+        errors_json =  json.dumps(errors, indent =4)
+        print errors_json
+    except IOError:
+        print "Could not open file %s." % (pjson_file)
+        sys.exit(1)
         
     
     
-    
\ No newline at end of file
+    
